@@ -136,6 +136,28 @@ gda_row_attributes_get_field (GdaRowAttributes *attrs, gint num)
 	return &attrs->_buffer[num];
 }
 
+/**
+ * gda_field_attributes_new
+ */
+GdaFieldAttributes *
+gda_field_attributes_new (void)
+{
+	GdaFieldAttributes *fa;
+
+	fa = GNOME_Database_FieldAttributes__alloc ();
+	return fa;
+}
+
+/**
+ * gda_field_attributes_free
+ */
+void
+gda_field_attributes_free (GdaFieldAttributes *fa)
+{
+	g_return_if_fail (fa != NULL);
+	CORBA_free (fa);
+}
+
 /**
  * gda_field_attributes_get_defined_size
  * @fa: a @GdaRowAttributes
@@ -248,6 +270,35 @@ gda_field_attributes_set_gdatype (GdaFieldAttributes *fa, GdaType type)
 	fa->gdaType = type;
 }
 
+/**
+ * gda_field_attributes_get_allow_null
+ * @fa: a #GdaFieldAttributes.
+ *
+ * Get the 'allow null' flag of the given field attributes.
+ *
+ * Returns: whether the given field allows null values or not.
+ */
+gboolean
+gda_field_attributes_get_allow_null (GdaFieldAttributes *fa)
+{
+	g_return_val_if_fail (fa != NULL, FALSE);
+	return fa->allowNull;
+}
+
+/**
+ * gda_field_attributes_set_allow_null
+ * @fa: a #GdaFieldAttributes.
+ * @allow:
+ *
+ * Sets the 'allow null' flag of the given field attributes.
+ */
+void
+gda_field_attributes_set_allow_null (GdaFieldAttributes *fa, gboolean allow)
+{
+	g_return_if_fail (fa != NULL);
+	fa->allowNull = allow;
+}
+
 /**
  * gda_field_get_actual_size
  * @field: a #GdaField
@@ -388,6 +439,29 @@ gda_field_set_gdatype (GdaField *field, GdaType type)
 	field->attributes.gdaType = type;
 }
 
+/**
+ * gda_field_get_allow_null
+ * @field: a #GdaField.
+ */
+gboolean
+gda_field_get_allow_null (GdaField *field)
+{
+	g_return_val_if_fail (field != NULL, FALSE);
+	return field->attributes.allowNull;
+}
+
+/**
+ * gda_field_set_allow_null
+ * @field: a #GdaField.
+ * @allow:
+ */
+void
+gda_field_set_allow_null (GdaField *field, gboolean allow)
+{
+	g_return_if_fail (field != NULL);
+	field->attributes.allowNull = allow;
+}
+
 /**
  * gda_field_is_null
  * @field: a #GdaField
