@@ -1,5 +1,5 @@
 /* GDA library
- * Copyright (C) 1998-2001 The Free Software Foundation
+ * Copyright (C) 1998-2002 The GNOME Foundation.
  *
  * AUTHORS:
  *	Rodrigo Moya <rodrigo@gnome-db.org>
@@ -27,7 +27,7 @@
 #include <bonobo/bonobo-i18n.h>
 #include <bonobo/bonobo-exception.h>
 
-#define PARENT_TYPE BONOBO_X_OBJECT_TYPE
+#define PARENT_TYPE BONOBO_OBJECT_TYPE
 
 struct _GdaServerConnectionPrivate {
 	GdaServerProvider *provider;
@@ -61,7 +61,7 @@ impl_Connection_open (PortableServer_Servant servant,
 	gboolean result;
 	GdaQuarkList *params;
 	GNOME_Database_Client client_copy;
-	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_x_object (servant);
+	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_object (servant);
 
 	bonobo_return_val_if_fail (GDA_IS_SERVER_CONNECTION (cnc), FALSE, ev);
 
@@ -85,7 +85,7 @@ impl_Connection_open (PortableServer_Servant servant,
 	result = TRUE;
 
 	/* add the new client to our list */
-	client_copy = CORBA_Object_duplicate (client, ev);
+	client_copy = bonobo_object_dup_ref ((Bonobo_Unknown) client, ev);
 	if (BONOBO_EX (ev))
 		gda_log_error (_("Could not duplicate client object. Client won't get notifications"));
 	else {
@@ -106,7 +106,7 @@ impl_Connection_close (PortableServer_Servant servant,
 {
 	gboolean result;
 	GList *l;
-	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_x_object (servant);
+	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_object (servant);
 
 	bonobo_return_val_if_fail (GDA_IS_SERVER_CONNECTION (cnc), FALSE, ev);
 
@@ -142,7 +142,7 @@ impl_Connection_close (PortableServer_Servant servant,
 static GNOME_Database_RecordsetList *
 impl_Connection_executeCommand (PortableServer_Servant servant,
 				const GNOME_Database_Command *cmd,
-				const GNOME_Database_ParameterList *params,
+				const Bonobo_PropertySet *params,
 				CORBA_Environment *ev)
 {
 	GList *recset_list;
@@ -150,7 +150,7 @@ impl_Connection_executeCommand (PortableServer_Servant servant,
 	gint count;
 	GNOME_Database_RecordsetList *seq;
 	GdaParameterList *param_list = NULL;
-	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_x_object (servant);
+	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_object (servant);
 
 	bonobo_return_val_if_fail (GDA_IS_SERVER_CONNECTION (cnc), NULL, ev);
 
@@ -185,7 +185,7 @@ impl_Connection_beginTransaction (PortableServer_Servant servant,
 				  CORBA_Environment *ev)
 {
 	gboolean result;
-	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_x_object (servant);
+	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_object (servant);
 
 	bonobo_return_val_if_fail (GDA_IS_SERVER_CONNECTION (cnc), FALSE, ev);
 
@@ -210,7 +210,7 @@ impl_Connection_commitTransaction (PortableServer_Servant servant,
 				   CORBA_Environment *ev)
 {
 	gboolean result;
-	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_x_object (servant);
+	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_object (servant);
 
 	bonobo_return_val_if_fail (GDA_IS_SERVER_CONNECTION (cnc), FALSE, ev);
 
@@ -234,7 +234,7 @@ impl_Connection_rollbackTransaction (PortableServer_Servant servant,
 				     CORBA_Environment *ev)
 {
 	gboolean result;
-	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_x_object (servant);
+	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_object (servant);
 
 	bonobo_return_val_if_fail (GDA_IS_SERVER_CONNECTION (cnc), FALSE, ev);
 
@@ -258,7 +258,7 @@ impl_Connection_supports (PortableServer_Servant servant,
 			  CORBA_Environment *ev)
 {
 	gboolean result;
-	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_x_object (servant);
+	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_object (servant);
 
 	bonobo_return_val_if_fail (GDA_IS_SERVER_CONNECTION (cnc), FALSE, ev);
 
@@ -269,16 +269,16 @@ impl_Connection_supports (PortableServer_Servant servant,
 static GNOME_Database_Recordset
 impl_Connection_getSchema (PortableServer_Servant servant,
 			   const GNOME_Database_Connection_Schema schema,
-			   const GNOME_Database_ParameterList *params,
+			   const Bonobo_PropertySet *params,
 			   CORBA_Environment *ev)
 {
 	GdaServerRecordset *recset;
 	GdaParameterList *plist;
-	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_x_object (servant);
+	GdaServerConnection *cnc = (GdaServerConnection *) bonobo_object (servant);
 
 	bonobo_return_val_if_fail (GDA_IS_SERVER_CONNECTION (cnc), CORBA_OBJECT_NIL, ev);
 
-	plist = gda_parameter_list_new_from_corba (params);
+	plist = gda_parameter_list_new_from_corba ((Bonobo_PropertySet *) params);
 	recset = gda_server_provider_get_schema (cnc->priv->provider, cnc, schema, plist);
 	gda_parameter_list_free (plist);
 
@@ -361,7 +361,7 @@ gda_server_connection_finalize (GObject *object)
 	parent_class->finalize (object);
 }
 
-BONOBO_X_TYPE_FUNC_FULL (GdaServerConnection,
+BONOBO_TYPE_FUNC_FULL (GdaServerConnection,
 			 GNOME_Database_Connection,
 			 PARENT_TYPE,
 			 gda_server_connection)
@@ -430,7 +430,7 @@ gda_server_connection_notify_action (GdaServerConnection *cnc,
 		client = (GNOME_Database_Client) l->data;
 		if (client != CORBA_OBJECT_NIL) {
 			CORBA_Environment ev;
-			GNOME_Database_ParameterList *corba_params;
+			Bonobo_PropertySet *corba_params;
 
 			corba_params = gda_parameter_list_to_corba (params);
 
@@ -461,10 +461,28 @@ gda_server_connection_add_error (GdaServerConnection *cnc, GdaError *error)
 
 /**
  * gda_server_connection_add_error_string
+ * @cnc: a #GdaServerConnection object.
+ * @msg: error message.
+ *
+ * Adds a new error to the given connection object. This is just a convenience
+ * function that simply creates a @GdaError and then calls
+ * @gda_server_connection_add_error.
  */
 void
 gda_server_connection_add_error_string (GdaServerConnection *cnc, const gchar *msg)
 {
+	GdaError *error;
+
+	g_return_if_fail (GDA_IS_SERVER_CONNECTION (cnc));
+	g_return_if_fail (msg != NULL);
+
+	error = gda_error_new ();
+	gda_error_set_description (error, msg);
+	gda_error_set_number (error, -1);
+	gda_error_set_source (error, g_get_prgname ());
+	gda_error_set_sqlstate (error, "-1");
+
+	gda_server_connection_add_error (cnc, error);
 }
 
 /**
